# Library Name

Collection of System G3 Visualization files' parsers and generators.

## Installation

The installation can be done with the package manager `pip`.

```bash
pip install g3visu
```

## Usage

Invoke from the terminal:

```bash
gen-visu --help
```

The package can also be used as a library:

```python
from g3visu import TypeInfo, SiteSVG
from g3visu.utils import SitesFileDownloader
```
